# racetime-bot

[![Discord](https://discordapp.com/api/guilds/660452709044060171/embed.png?style=shield)](https://discord.gg/65cvHG3)

A Python library to help you create chat bots for
[racetime.gg](https://racetime.gg).

## What is this for?

The racetime application allows categories to set up their own bots, which can
interact with ongoing races in order to supply information and similar actions.

This library provides a basic template for creating these bots.

## Setup guide

### Requirements

* Python 3.7 or greater.

### Installation

Install via pip/PyPI:

```pip install racetime-bot```

## How to get started

You should read the racetime-app documentation on
[Category bots](https://github.com/deains/racetime-app/wiki/Category-bots) to
understand what you need to get started. You don't need a thorough
understanding of the technical side of things to build your own bot, but it is
helpful to be able to understand how messages are structured, and how they are
used.

For an example of this library in use, you can look at the implementation of
[ootr-randobot](https://github.com/deains/ootr-randobot). This should give you
a decent insight into how you need to structure your bot. Feel free to re-use
the code given in that repository in order to generate a bot yourself!
